Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(677)

Unified Diff: ui/views/selection_controller_delegate.h

Issue 2413223003: Views:: Make Labels support text selection. (Closed)
Patch Set: Rebase Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/selection_controller.cc ('k') | ui/views/style/platform_style.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/selection_controller_delegate.h
diff --git a/ui/views/selection_controller_delegate.h b/ui/views/selection_controller_delegate.h
index f0b500090e648d7452043c721adafc6ec01c472c..d9c823d607d3692f527dc2d7418860ae17a5fc5c 100644
--- a/ui/views/selection_controller_delegate.h
+++ b/ui/views/selection_controller_delegate.h
@@ -24,10 +24,13 @@ class VIEWS_EXPORT SelectionControllerDelegate {
// Returns true if the associated text view is read only.
virtual bool IsReadOnly() const = 0;
+ // Returns whether the associated view supports drag-and-drop.
+ virtual bool SupportsDrag() const = 0;
// Returns whether there is a drag operation originating from the associated
// view.
virtual bool HasTextBeingDragged() const = 0;
// Sets whether text is being dragged from the associated view.
virtual void SetTextBeingDragged(bool value) = 0;
// Returns the height of the associated view.
virtual int GetViewHeight() const = 0;
@@ -24,10 +24,13 @@ class VIEWS_EXPORT SelectionControllerDelegate {
// view.
virtual bool HasTextBeingDragged() const = 0;
- // Sets whether text is being dragged from the associated view.
+ // Sets whether text is being dragged from the associated view. Called only if
+ // the delegate supports drag.
virtual void SetTextBeingDragged(bool value) = 0;
// Returns the height of the associated view.
« no previous file with comments | « ui/views/selection_controller.cc ('k') | ui/views/style/platform_style.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698